flutter_powerauth_mobile_sdk_plugin library

Classes

NativeObjectCmdData
Data accepted in debugCommand() function.
NativeObjectRegister
The Register class extends NativeObjectRegister functionality for this test suite purposes.
ObjectsCount
PinTestResult
Object representing a PIN strength test result.
PowerAuth
Main class for interacting with the PowerAuth Mobile Flutter SDK.
PowerAuthActivation
Contains activation data required for the activation creation. Use one of the factory constructors to create an instance based on the activation type.
PowerAuthActivationCode
Contains parsed components from a user-provided activation.
PowerAuthActivationCodeUtil
Provides utility functions related to PowerAuth activation codes nd PIN strength. The PowerAuthActivationCodeUtil provides various set of methods for parsing and validating activation codes.
PowerAuthActivationStatus
Represents the complete status of the activation.
PowerAuthAuthentication
Represents a multi-factor authentication object specifying which factors to use for an operation. Use the factory constructors to create instances for different factor combinations.
PowerAuthBasicHttpAuthentication
Basic HTTP Authentication data.
PowerAuthBiometricPrompt
Defines strings used to display the platform-specific biometric authentication dialog.
PowerAuthBiometricStatus
Contains information about the availability of biometric authentication for a PowerAuth instance.
PowerAuthBiometryConfiguration
Contains configuration for biometry-related features.
PowerAuthClientConfiguration
Class that contains configuration for the RESTful API client used internally by the SDK.
PowerAuthConfiguration
Contains configuration data for a single PowerAuth instance.
PowerAuthCreateActivationResult
Success object returned by the createActivation call.
PowerAuthCryptoUtils
Provides core cryptographic utilities based on PowerAuthCore.
PowerAuthDebug
This class provides debug features for the PowerAuth SDK. It allows enabling detailed logging of native code calls and dumping the contents of the native object register. Note that these features are only effective in debug builds of the SDK.
PowerAuthDevicePublicKeyData
Exported device public key data.
PowerAuthEncryptedRequest
Encrypted request body and HTTP headers produced by PowerAuthEncryptor.
PowerAuthEncryptor
A stateful, single-use end-to-end encryptor.
PowerAuthEnvironmentInfo
Class representing the environment information for the PowerAuth SDK. This includes system details, application version or device information.
PowerAuthExternalPendingOperation
iOS specific
PowerAuthHttpHeader
Custom HTTP header data.
PowerAuthKeychainConfiguration
Android specific
PowerAuthLog
A single log entry produced by the PowerAuth SDK.
PowerAuthLoggingConfig
Configuration for PowerAuth SDK logging.
PowerAuthOIDCParameters
Parameters for an activation via OpenID connect provider.
PowerAuthPassword
Represents a secure storage for a user's password or PIN.
PowerAuthPasswordChangeData
Native-backed data required to finish a two-step password change.
PowerAuthProtocolUpgradeResult
Result of a successful PowerAuth protocol upgrade.
PowerAuthSecureVaultKey
A protocol 4.0 Secure Vault key that can derive purpose-specific keys.
PowerAuthSharingConfiguration
iOS specific
PowerAuthTimeSynchronizationService
The PowerAuthTimeSynchronizationService allows you to synchronize the local device time with the PowerAuth Server and then get the synchronized time.
PowerAuthToken
PowerAuthTokenStore
The PowerAuthTokenStore provides interface for managing access tokens. The class is using Keychain as underlying storage for received data. Note that the whole store's interface is thread safe, but it's not recommended to query for the same token in overlapping asynchronous requests. This usage may lead to leaking tokens on the PowerAuth server.
PowerAuthUserAddress
The PowerAuthUserAddress object contains address of end-user.
PowerAuthUserInfo
The PowerAuthUserInfo object contains additional information about the end-user.
PowerAuthUtils
The PowerAuthUtils class provides utility methods for the PowerAuth SDK.

Enums

NativeObjectType
Type of native object.
PinTestIssue
Issues found during the PIN strength test.
PowerAuthActivationState
Defines all possible states of activation. The state is part of the information received in PowerAuthActivationStatus.
PowerAuthAlgorithm
Algorithm used for communication with the PowerAuth Server.
PowerAuthBiometryStatus
Defines various states of biometric authentication support on the system. The status may change during the application lifetime, unless it's notSupported.
PowerAuthBiometryType
Defines biometry types supported on the system. In case a device supports multiple biometry types, then generic is returned.
PowerAuthDevicePublicKeyFormat
Output format used when exporting device public keys.
PowerAuthEncryptorScope
Scope of an end-to-end encryptor.
PowerAuthErrorCode
Error codes that can be reported by the PowerAuth SDK.
PowerAuthExternalPendingOperationType
iOS specific
PowerAuthKeychainProtection
Android specific
PowerAuthLogLevel
Public log levels emitted by the PowerAuth SDK.
PowerAuthSecureVaultKeyId
Identifies a base key available from the protocol 4.0 Secure Vault.
PowerAuthSignatureKeyId
Identifies a key used for digital signature calculation or verification.
PowerAuthSignatureKeyType
Cryptographic type of a signature key.

Exceptions / Errors

PowerAuthException
Exception thrown by the PowerAuth SDK.