ObjectsCount class

Constructors

ObjectsCount({required int valid, required int invalid})

Properties

hashCode → int
The hash code for this object.
no setterinherited
invalid → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → dynamic
no setter
valid → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited