PinTestIssue enum

Issues found during the PIN strength test.

Inheritance
Available extensions

Values

notUnique → const PinTestIssue

Not enough unique digits found.

repeatingChars → const PinTestIssue

Too many repeating characters.

patternFound → const PinTestIssue

There is a pattern in this pin (for example 1357).

possiblyDate → const PinTestIssue

Tested pin could be a date (for example 2512 as birthday - 25th of december).

frequentlyUsed → const PinTestIssue

Tested pin is in TOP used pins (like 1234 as number 1 used pin).

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PinTestIssue>
A constant List of the values in this enum, in order of their declaration.