fallbackToSharedBiometryKey property
Android specific
Set whether fallback to a shared, legacy biometry key is enabled. By default, this is enabled for compatibility
reasons. If enabled, PowerAuth performs an additional lookup for a legacy biometric key previously shared
between multiple PowerAuth object instances.
If your application uses multiple PowerAuth instances, it's recommended to set this configuration to false.
This is because the native SDK doesn't properly handle multiple activations with the shared biometric key.
If set to false, the shared key will no longer be accessible, and you may need to reconfigure the biometric factor
for the existing activations on your PowerAuth object instances.
The default value is true, so the fallback is enabled.
Implementation
final bool fallbackToSharedBiometryKey;