PowerAuthClientConfiguration class

Class that contains configuration for the RESTful API client used internally by the SDK.

Configurations returned by PowerAuth.clientConfiguration contain only settings that the native SDK can expose. Request-interceptor settings are input-only and are not present in returned configurations.

Constructors

PowerAuthClientConfiguration({bool enableUnsecureTraffic = false, double connectionTimeout = 20.0, double readTimeout = 20.0, List<PowerAuthHttpHeader>? customHttpHeaders, PowerAuthBasicHttpAuthentication? basicHttpAuthentication})
PowerAuthClientConfiguration.fromMap(Map<String, dynamic> map)
factory

Properties

connectionTimeout double
Connection timeout in seconds. Defaults to 20 seconds.
final
enableUnsecureTraffic bool
Defines whether unsecured connection is allowed. Defaults to false.
final
hashCode int
The hash code for this object.
no setterinherited
readTimeout double
Read timeout in seconds. Be aware that this parameter is ignored on Apple platforms. Defaults to 20 seconds.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited