PowerAuthBiometricPrompt class
Defines strings used to display the platform-specific biometric authentication dialog.
Constructors
Properties
- cancelButtonTitle → String?
-
iOS specific
final
- fallbackButtonTitle → String?
-
iOS specific
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- promptMessage → String
-
Prompt message displayed to the user.
Example: "Please authorize the payment with the biometric sensor"
final
- promptSubtitle → String?
-
Android specific
final
- promptTitle → String?
-
Android specific
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited