PowerAuthBiometryConfiguration class
Contains configuration for biometry-related features.
Constructors
- PowerAuthBiometryConfiguration({bool? invalidateBiometricFactorAfterChange, bool fallbackToDevicePasscode = false, bool confirmBiometricAuthentication = false, bool authenticateOnBiometricKeySetup = true, bool useLegacySymmetricKey = false})
-
PowerAuthBiometryConfiguration.fromMap(Map<
String, dynamic> map) -
factory
Properties
- authenticateOnBiometricKeySetup → bool
-
Android specific
final
- confirmBiometricAuthentication → bool
-
Android specific
final
- fallbackToDevicePasscode → bool
-
iOS specific
final
-
Android specific
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalidateBiometricFactorAfterChange → bool
-
Set whether the key protected with the biometry is invalidated if fingers are added or
removed, or if the user re-enrolls for face. The default value depends on platform:
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useLegacySymmetricKey → bool
-
Android specific
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited