PowerAuthEnvironmentInfo class
Class representing the environment information for the PowerAuth SDK. This includes system details, application version or device information.
Constructors
- PowerAuthEnvironmentInfo({required String systemName, required String systemVersion, String? applicationVersion, String? applicationIdentifier, required String deviceManufacturer, required String deviceId, required String sdkVersion})
- PowerAuthEnvironmentInfo.fromJson(Map json)
-
factory
Properties
- applicationIdentifier ↔ String?
-
Host application identifier, for example "com.wultra.demoapp"
getter/setter pair
- applicationVersion ↔ String?
-
Application version, e.g. "1.0.0".
getter/setter pair
- deviceId ↔ String
-
Device ID, for example "iPhone9,2"
getter/setter pair
- deviceManufacturer ↔ String
-
For example "apple" or "Samsung"
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkVersion ↔ String
-
PowerAuth Flutter SDK version, for example "4.0.0"
getter/setter pair
- systemName ↔ String
-
System name, for example "iOS", "Android", "iPadOS", ...
getter/setter pair
- systemVersion ↔ String
-
Version of the system
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited