PowerAuthLog class
A single log entry produced by the PowerAuth SDK.
Constructors
- PowerAuthLog(PowerAuthLogLevel level, String message, {String? tag, DateTime? timestamp})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → PowerAuthLogLevel
-
Severity of the log entry.
final
- message → String
-
Human-readable log text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
Optional tag identifying the log origin (e.g.
PowerAuthNativeSDK).final - timestamp → DateTime
-
When this log entry was created.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited