PowerAuthUserAddress class
The PowerAuthUserAddress object contains address of end-user.
Constructors
-
PowerAuthUserAddress(Map<
String, dynamic> ? claims) -
Construct object with map with claims.
claimsMap with all claims representing information about the user's address.
Properties
-
allClaims
→ Map<
String, dynamic> -
Full collection of claims received from the server.
no setter
- country → String?
-
Country name component.
no setter
- formatted → String?
-
The full mailing address, with multiple lines if necessary.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- locality → String?
-
City or locality component.
no setter
- postalCode → String?
-
Zip code or postal code component.
no setter
- region → String?
-
State, province, prefecture or region component.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- street → String?
-
The street address component, which may include house number, street name, post office box,
and other multi-line information.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited